@@ -15,15 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: AutoJSContextStack.cpp,v 1.3 2006/03/05 20:54:32 chpe Exp $
+ *  $Id: AutoJSContextStack.cpp,v 1.4 2006/05/10 18:06:59 chpe Exp $
  */
 
 #include "mozilla-config.h"
 #include "config.h"
 
-#include "AutoJSContextStack.h"
+#include <nsServiceManagerUtils.h>
 
-#include <nsIServiceManager.h>
+#include "AutoJSContextStack.h"
 
 AutoJSContextStack::~AutoJSContextStack()
 {
