@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.142 2006/05/15 18:12:31 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.144 2006/08/07 20:25:17 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -85,7 +85,6 @@
 #include "ephy-permission-manager.h"
 #include "mozilla-embed.h"
 #include "mozilla-notifiers.h"
-#include "MozillaPrivate.h"
 #include "mozilla-x509-cert.h"
 
 #include "EphyBrowser.h"
@@ -96,6 +95,8 @@
 
 #include "mozilla-embed-single.h"
 
+#include "AutoJSContextStack.h"
+
 #define MOZILLA_PROFILE_DIR  "/mozilla"
 #define MOZILLA_PROFILE_NAME "epiphany"
 #define MOZILLA_PROFILE_FILE "prefs.js"
@@ -585,6 +586,11 @@ impl_init (EphyEmbedSingle *esingle)
 {
 	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (esingle);
 
+#ifdef MOZ_ENABLE_XPRINT
+	/* XPrint? No, thanks! */
+	g_unsetenv ("XPSERVERLIST");
+#endif
+
 #ifdef HAVE_GECKO_1_9
 	NS_LogInit ();
 #endif
@@ -1091,8 +1097,12 @@ impl_open_window (EphyEmbedSingle *single,
 		  const char *name,
 		  const char *features)
 {
-	nsCOMPtr<nsIDOMWindow> domWindow;
+	nsresult rv;
+	AutoJSContextStack stack;
+	rv = stack.Init ();
+	if (NS_FAILED (rv)) return NULL;
 
+	nsCOMPtr<nsIDOMWindow> domWindow;
 	if (parent)
 	{
 		EphyBrowser *browser;
