@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.45 2006/01/29 14:30:15 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.48 2006/05/29 19:49:21 chpe Exp $
  */
 
 #include "config.h"
@@ -34,6 +34,7 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-directory.h>
 #include <libxml/xmlreader.h>
 
 /* bug http://bugzilla.gnome.org/show_bug.cgi?id=156687 */
@@ -61,6 +62,7 @@ static GHashTable *files = NULL;
 static GHashTable *mime_table = NULL;
 
 static gboolean have_private_profile = FALSE;
+static gboolean keep_temp_directory = FALSE; /* for debug purposes */
 static char *dot_dir = NULL;
 static char *tmp_dir = NULL;
 static GList *del_on_exit = NULL;
@@ -257,7 +259,9 @@ ephy_dot_dir (void)
 }
 
 gboolean
-ephy_file_helpers_init (gboolean private_profile,
+ephy_file_helpers_init (const char *profile_dir,
+			gboolean private_profile,
+			gboolean keep_temp_dir,
 			GError **error)
 {
 	const char *uuid;
@@ -281,8 +285,13 @@ ephy_file_helpers_init (gboolean private_profile,
 				       (GDestroyNotify) g_free);
 
 	have_private_profile = private_profile;
+	keep_temp_directory = keep_temp_dir;
 
-	if (private_profile)
+	if (private_profile && profile_dir != NULL)
+	{
+		dot_dir = g_strdup (profile_dir);
+	}
+	else if (private_profile)
 	{
 		if (ephy_file_tmp_dir () == NULL)
 		{
@@ -336,15 +345,23 @@ ephy_file_helpers_shutdown (void)
 		mime_table = NULL;
 	}
 
+	g_free (dot_dir);
+	dot_dir = NULL;
+
 	if (tmp_dir != NULL)
 	{
-		rmdir (tmp_dir);
+		if (!keep_temp_directory)
+		{
+			/* recursively delete the contents */
+			ephy_file_delete_directory (tmp_dir);
+
+			/* delete the directory itself too */
+			rmdir (tmp_dir);
+		}
+
 		g_free (tmp_dir);
 		tmp_dir = NULL;
 	}
-
-	g_free (dot_dir);
-	dot_dir = NULL;
 }
 
 gboolean
@@ -471,8 +488,7 @@ failed:
 void
 ephy_file_delete_on_exit (const char *path)
 {
-	del_on_exit = g_list_prepend (del_on_exit,
-				      g_strdup (path));
+	/* does nothing now */
 }
 
 static void
@@ -785,6 +801,7 @@ ephy_file_launch_application (GnomeVFSMimeApplication *application,
 
 	uris = g_list_prepend (NULL, uri);
 
+	/* FIXME multihead! */
 	screen = gdk_screen_get_default ();
 	envp = my_gdk_spawn_make_environment_for_screen (screen, NULL);
 	
@@ -876,10 +893,15 @@ launch_desktop_item (const char *desktop_file,
 		     GError **error)
 {
 	GnomeDesktopItem *item = NULL;
+	GdkScreen *screen;
 	GList *uris = NULL;
 	char *canonical;
 	int ret = -1;
-	char *envp[2] = { EPHY_UUID_ENVSTRING, NULL };
+	char **envp;
+	
+	/* FIXME multihead! */
+	screen = gdk_screen_get_default ();
+	envp = my_gdk_spawn_make_environment_for_screen (screen, NULL);
 
 	item = gnome_desktop_item_new_from_file (desktop_file, 0, NULL);
 	if (item == NULL) return FALSE;
@@ -895,6 +917,7 @@ launch_desktop_item (const char *desktop_file,
 
 	g_list_foreach (uris, (GFunc) g_free, NULL);
 	g_list_free (uris);
+	g_strfreev (envp);
 	gnome_desktop_item_unref (item);
 
 	return ret;
@@ -1152,3 +1175,9 @@ ephy_file_monitor_cancel (EphyFileMonitor *monitor)
 	g_free (monitor->uri);
 	g_free (monitor);
 }
+
+void
+ephy_file_delete_directory (const char *path)
+{
+	/* FIXME not implemented yet */
+}
