@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-menu.c,v 1.36 2005/11/08 12:46:43 chpe Exp $
+ *  $Id: ephy-encoding-menu.c,v 1.37 2006/03/02 21:23:34 jframeau Exp $
  */
 
 #include "config.h"
@@ -318,11 +318,12 @@ ephy_encoding_menu_view_dialog_cb (GtkAction *action, EphyEncodingMenu *menu)
 {
 	if (menu->priv->dialog == NULL)
 	{
+		EphyEncodingDialog **dialog = &menu->priv->dialog;
 		menu->priv->dialog = ephy_encoding_dialog_new
 					(menu->priv->window);
 
 		g_object_add_weak_pointer(G_OBJECT (menu->priv->dialog),
-					  (gpointer *) &menu->priv->dialog);
+					  (gpointer *)dialog);
 	}
 
 	ephy_dialog_show (EPHY_DIALOG (menu->priv->dialog));
