@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.102 2006/01/27 22:14:43 paharvey Exp $
+ *  $Id: ephy-history-window.c,v 1.106 2006/08/07 20:49:51 chpe Exp $
  */
 
 #include "config.h"
@@ -223,7 +223,7 @@ static const GtkRadioActionEntry ephy_history_radio_entries [] =
 	  N_("Show only the title column"), VIEW_TITLE },
 	{ "ViewAddress", NULL, N_("_Address"), NULL,
 	  N_("Show only the address column"), VIEW_ADDRESS },
-	{ "ViewTitleAddress", NULL, N_("T_itle and Address"), NULL,
+	{ "ViewTitleAddress", NULL, N_("Title a_nd Address"), NULL,
 	  N_("Show both the title and address columns"),
 	  VIEW_TITLE_AND_ADDRESS } 
 };
@@ -283,9 +283,12 @@ cmd_clear (GtkAction *action,
 {
 	if (editor->priv->confirmation_dialog == NULL)
 	{
+		GtkWidget **confirmation_dialog;
+
 		editor->priv->confirmation_dialog = confirmation_dialog_construct (editor);
+		confirmation_dialog = &editor->priv->confirmation_dialog;
 		g_object_add_weak_pointer (G_OBJECT (editor->priv->confirmation_dialog),
-					   (gpointer *) &editor->priv->confirmation_dialog);
+					   (gpointer *) confirmation_dialog);
 	}
 
 	gtk_widget_show (editor->priv->confirmation_dialog);
@@ -489,7 +492,7 @@ cmd_bookmark_link (GtkAction *action,
 		location = ephy_node_get_property_string (node, EPHY_NODE_PAGE_PROP_LOCATION);
 		title = ephy_node_get_property_string (node, EPHY_NODE_PAGE_PROP_TITLE);
 
-		ephy_bookmarks_ui_add_bookmark (location, title);
+		ephy_bookmarks_ui_add_bookmark (GTK_WINDOW (editor), location, title);
 	}
 
 	g_list_free (selection);
@@ -628,9 +631,10 @@ ephy_history_window_finalize (GObject *object)
 
 	if (editor->priv->window)
 	{
+		GtkWidget **window = &editor->priv->window;
 		g_object_remove_weak_pointer
                         (G_OBJECT(editor->priv->window),
-                         (gpointer *)&editor->priv->window);
+                         (gpointer *)window);
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -1356,18 +1360,21 @@ void
 ephy_history_window_set_parent (EphyHistoryWindow *ebe,
 				GtkWidget *window)
 {
+	GtkWidget **widget;
 	if (ebe->priv->window)
 	{
+		widget = &ebe->priv->window;
 		g_object_remove_weak_pointer
                         (G_OBJECT(ebe->priv->window),
-                         (gpointer *)&ebe->priv->window);
+                         (gpointer *)widget);
 	}
 
 	ebe->priv->window = window;
+	widget = &ebe->priv->window;
 
 	g_object_add_weak_pointer
                         (G_OBJECT(ebe->priv->window),
-                         (gpointer *)&ebe->priv->window);
+			(gpointer *)widget);
 
 }
 
