@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.h,v 1.20 2005/03/14 18:41:35 chpe Exp $
+ *  $Id: window-commands.h,v 1.25 2006/08/07 20:42:44 chpe Exp $
  */
 
 #include <gtk/gtkaction.h>
@@ -28,18 +28,9 @@ void window_cmd_edit_find	(GtkAction *action,
 void window_cmd_view_stop	(GtkAction *action,
 				 EphyWindow *window);
 
-void window_cmd_go_back		(GtkAction *action,
-				 EphyWindow *window);
-
-void window_cmd_go_forward	(GtkAction *action,
-				 EphyWindow *window);
-
 void window_cmd_go_location	(GtkAction *action,
 				 EphyWindow *window);
 
-void window_cmd_go_up		(GtkAction *action,
-				 EphyWindow *window);
-
 void window_cmd_go_myportal	(GtkAction *action,
 				 EphyWindow *window);
 
@@ -103,6 +94,9 @@ void window_cmd_edit_copy	(GtkAction *action,
 void window_cmd_edit_paste	(GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_edit_delete	(GtkAction *action,
+				 EphyWindow *window);
+
 void window_cmd_edit_select_all (GtkAction *action,
 				 EphyWindow *window);
 
@@ -127,12 +121,18 @@ void window_cmd_view_zoom_normal(GtkAction *action,
 void window_cmd_view_page_source(GtkAction *action,
 				 EphyWindow *window);
 
+void window_cmd_view_page_security_info (GtkAction *action,
+					 EphyWindow *window);
+
 void window_cmd_go_history	(GtkAction *action,
 				 EphyWindow *window);
 
 void window_cmd_edit_personal_data (GtkAction *action,
 				    EphyWindow *window);
 
+void window_cmd_edit_certificates (GtkAction *action,
+				    EphyWindow *window);
+
 void window_cmd_edit_prefs      (GtkAction *action,
 				 EphyWindow *window);
 
@@ -166,7 +166,3 @@ void window_cmd_load_location   (GtkAction *action,
 void window_cmd_browse_with_caret (GtkAction *action,
 				   EphyWindow *window);
 
-#ifdef HAVE_X11_XF86KEYSYM_H
-void window_cmd_go_home		(GtkAction *action,
-				 EphyWindow *window);
-#endif
